var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withStyles } from '@material-ui/core/styles';
import Snackbar from '@material-ui/core/Snackbar';
import SnackbarContent from '@material-ui/core/SnackbarContent';
import { styles, getTransitionStyles } from './SnackbarItem.styles';
import { variantIcon, TransitionComponent, getTransitionDirection } from './SnackbarItem.util';

class SnackbarItem extends Component {
    constructor(...args) {
        var _temp;

        return _temp = super(...args), this.getTransitionStyles = index => {
            return getTransitionStyles(index, this.props.anchorOrigin);
        }, this.handleClose = key => (event, reason) => {
            if (reason === 'clickaway') return;
            this.props.onClose(key);
        }, _temp;
    }

    render() {
        const _props = this.props,
              {
            classes,
            level,
            snack: { message, variant, key, open },
            onExited,
            anchorOrigin
        } = _props,
              props = _objectWithoutProperties(_props, ['classes', 'level', 'snack', 'onExited', 'anchorOrigin']);

        return React.createElement(
            Snackbar,
            _extends({}, props, {
                open: open,
                TransitionProps: {
                    direction: getTransitionDirection(anchorOrigin)
                },
                anchorOrigin: anchorOrigin,
                style: this.getTransitionStyles(level),
                onClose: this.handleClose(key),
                onExited: event => onExited(key)
            }),
            React.createElement(SnackbarContent, {
                className: classes[variant],
                'aria-describedby': 'client-snackbar',
                message: React.createElement(
                    'span',
                    { id: 'client-snackbar', className: classes.message },
                    React.createElement(
                        'span',
                        { className: classes.iconVariant },
                        variantIcon[variant]
                    ),
                    message
                )
            })
        );
    }
}

SnackbarItem.propTypes = {
    classes: PropTypes.object.isRequired,
    level: PropTypes.number.isRequired,
    snack: PropTypes.shape({
        message: PropTypes.string.isRequired,
        variant: PropTypes.oneOf(['error', 'success', 'warning', 'info']).isRequired,
        key: PropTypes.number.isRequired,
        open: PropTypes.bool.isRequired
    }).isRequired,
    onClose: PropTypes.func.isRequired,
    onExited: PropTypes.func.isRequired,
    anchorOrigin: PropTypes.object
};

SnackbarItem.defaultProps = {
    autoHideDuration: 5000,
    anchorOrigin: {
        vertical: 'bottom',
        horizontal: 'left'
    },
    TransitionComponent: TransitionComponent
};

export default withStyles(styles)(SnackbarItem);