var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import SnackbarContext from './SnackbarContext';
import SnackbarItem from './SnackbarItem';
import { TRANSITION_DELAY, TRANSITION_DOWN_DURATION } from './utils/constants';

class SnackbarProvider extends Component {
    constructor(...args) {
        var _temp;

        return _temp = super(...args), this.state = { snacks: [] }, this.queue = [], this.handlePresentSnackbar = (variant, message) => {
            this.queue.push({
                message,
                variant,
                open: true,
                key: new Date().getTime()
            });
            this.handleDisplaySnack();
        }, this.handleDisplaySnack = () => {
            if (this.state.snacks.length >= this.props.maxSnack) {
                return this.handleDismissOldest();
            }
            return this.processQueue();
        }, this.processQueue = () => {
            if (this.queue.length > 0) {
                const newOne = this.queue.shift();
                let snacks = JSON.parse(JSON.stringify(this.state.snacks));
                this.setState({
                    snacks: [...snacks, newOne]
                });
            }
        }, this.handleDismissOldest = () => {
            let snacks = JSON.parse(JSON.stringify(this.state.snacks));
            snacks = snacks.filter(item => item.open === true);
            snacks[0].open = false;
            this.setState({ snacks });
        }, this.handleCloseSnack = key => {
            let snacks = JSON.parse(JSON.stringify(this.state.snacks));
            snacks.find(item => item.key === key).open = false;
            this.setState({ snacks });
        }, this.handleExitedSnack = key => {
            const enterDelay = TRANSITION_DELAY + TRANSITION_DOWN_DURATION + 40;
            let snacks = JSON.parse(JSON.stringify(this.state.snacks));
            snacks = snacks.filter(item => item.key !== key);
            this.setState({ snacks }, () => {
                setTimeout(this.handleDisplaySnack, enterDelay);
            });
        }, _temp;
    }

    /**
     * Adds a new snackbar to the queue to be presented.
     * @param {string} variant - type of the snackbar. can be: 
     * (success, error, warning, info)
     * @param {string} message - text of the notification
     */


    /**
     * Display snack if there's space for it.
     * Otherwise, immediately begin dismissing the 
     * oldest message to start showing the new one.
     */


    /**
     * Display items (notifications) in the queue
     * if there's space for them
     */


    /**
     * Hide oldest snackbar on the screen because 
     * there exists a new one which we have to display.
     */


    /**
     * Hide a snackbar after its timeout.
     * @param {number} key - id of the snackbar we want to hide
     */


    /**
     * When we set open attribute of a snackbar
     * to false (i.e. after we hide a snackbar),
     * it leaves the screen and immediately after
     * leaving animation is done, this method gets 
     * called. We remove the hidden snackbar from 
     * state and then display notifications waiting 
     * in the queue (if any).
     * @param {number} key - id of the snackbar we want to remove
     */


    render() {
        const _props = this.props,
              { children, maxSnack } = _props,
              props = _objectWithoutProperties(_props, ['children', 'maxSnack']);
        return React.createElement(
            SnackbarContext.Provider,
            { value: this.handlePresentSnackbar },
            React.createElement(
                Fragment,
                null,
                children,
                this.state.snacks.map((snack, index) => React.createElement(SnackbarItem, _extends({}, props, {
                    key: snack.key,
                    level: index,
                    snack: snack,
                    onClose: this.handleCloseSnack,
                    onExited: this.handleExitedSnack
                })))
            )
        );
    }
}

SnackbarProvider.propTypes = {
    children: PropTypes.element.isRequired, //require one child
    /**
     * Maximum snackbars that can be stacked 
     * on top of one another
     */
    maxSnack: PropTypes.number
};

SnackbarProvider.defaultProps = {
    maxSnack: 3
};

export default SnackbarProvider;